@@ -1,23 +1,22 @@
 // realconsole.cpp
-// Revision 6-mar-2004
+// Revision 14-may-2005
 
 #include "realconsole.h"
 
 #ifndef NO_CURSES
 
-#include <termios.h>
-#endif
-// NO_CURSES
+#include <ncurses.h>
+#include <term.h>
 
+#endif
+
+#include <termios.h>
 #include <unistd.h>
 #include <fcntl.h>
 #include <sys/poll.h>
 
-#include <ncurses.h>
-#include <term.h>
 #include <stdlib.h>
 #include <sys/ioctl.h>
-#include <termios.h>
 
 // This is from ncurses.
 #ifdef TIOCGSIZE
@@ -556,7 +555,8 @@ bool readkey (ReadType type, char & result, bool)
 	l= read (STDIN_FILENO, buffer, lbuf);
 	if (l < 1 && type == ReadWait)
 	{
-		do {
+		do
+		{
 			do_poll ();
 			l= read (STDIN_FILENO, buffer, lbuf);
 		} while (l < 1);
@@ -581,7 +581,11 @@ bool readkey (ReadType type, char & result, bool)
 	#endif
 
 	if (charpending.empty () )
+	{
+		if (reset_blocking_mode)
+			fcntl (STDIN_FILENO, F_SETFL, 0);
 		return false;
+	}
 	else
 	{
 		#ifndef NO_CURSES
@@ -624,8 +628,10 @@ bool readkey (ReadType type, char & result, bool)
 		}
 		#else
 
-		result= charpending [0];
-		charpending.erase (0, 1);
+		//result= charpending [0];
+		//charpending.erase (0, 1);
+		outputpending+= charpending;
+		charpending.erase ();
 
 		#endif
 	}
